@@ -27,7 +27,7 @@ from idds.orm import (transforms as orm_transforms,
 
 @transactional_session
 def add_transform(request_id, workload_id, transform_type, transform_tag=None, priority=0,
-                  status=TransformStatus.New, locking=TransformLocking.Idle,
+                  status=TransformStatus.New, substatus=TransformStatus.New, locking=TransformLocking.Idle,
                   retries=0, expired_at=None, transform_metadata=None, workprogress_id=None, session=None):
     """
     Add a transform.
@@ -50,7 +50,8 @@ def add_transform(request_id, workload_id, transform_type, transform_tag=None, p
     """
     transform_id = orm_transforms.add_transform(request_id=request_id, workload_id=workload_id,
                                                 transform_type=transform_type, transform_tag=transform_tag,
-                                                priority=priority, status=status, locking=locking, retries=retries,
+                                                priority=priority, status=status, substatus=substatus,
+                                                locking=locking, retries=retries,
                                                 expired_at=expired_at, transform_metadata=transform_metadata,
                                                 workprogress_id=workprogress_id, session=session)
     return transform_id
@@ -205,7 +206,7 @@ def update_transform(transform_id, parameters, session=None):
 def add_transform_outputs(transform, transform_parameters, input_collections=None, output_collections=None, log_collections=None,
                           update_input_collections=None, update_output_collections=None, update_log_collections=None,
                           new_contents=None, update_contents=None, new_processing=None, update_processing=None,
-                          messages=None, message_bulk_size=1000, session=None):
+                          messages=None, message_bulk_size=10000, session=None):
     """
     For input contents, add corresponding output contents.
 
