@@ -32,7 +32,7 @@ from idds.common.constants import (RequestType, RequestStatus, RequestLocking,
                                    MessageType, MessageStatus, MessageLocking, MessageSource)
 from idds.common.utils import date_to_str
 from idds.orm.base.enum import EnumSymbol
-from idds.orm.base.types import JSON, EnumWithValue
+from idds.orm.base.types import JSON, JSONString, EnumWithValue
 from idds.orm.base.session import BASE, DEFAULT_SCHEMA_NAME
 from idds.common.constants import (SCOPE_LENGTH, NAME_LENGTH)
 
@@ -489,7 +489,7 @@ class Content(BASE, ModelBase):
     updated_at = Column("updated_at", DateTime, default=datetime.datetime.utcnow, onupdate=datetime.datetime.utcnow)
     accessed_at = Column("accessed_at", DateTime, default=datetime.datetime.utcnow, onupdate=datetime.datetime.utcnow)
     expired_at = Column("expired_at", DateTime)
-    content_metadata = Column(JSON())
+    content_metadata = Column(JSONString())
 
     _table_args = (PrimaryKeyConstraint('content_id', name='CONTENTS_PK'),
                    # UniqueConstraint('name', 'scope', 'coll_id', 'content_type', 'min_id', 'max_id', name='CONTENT_SCOPE_NAME_UQ'),
